@@ -906,7 +906,7 @@ def do_changelog(packages):
         #command += "%s/%s_%s/changelog" % (pkg, pkg, ver)
         # (gjw 30 Dec 2004) command += "%s" % (pkg)
         # (gjw 23 Apr 2006) Try changelog: command += "changelogs/%s" % (changelog_path)
-        command += "changelog:" + p
+        command += "changelog:" + pkg
         command += " 2> /dev/null"
         perform.execute(command)
 
