@@ -80,7 +80,7 @@ def help(verbose):
     if verbose == 0:
         print """Common JIG commands:
 
- update         Update the list of down-loadable packages
+ update         Update the list of downloadable packages
 
  new            List packages that became available since last update
  newupgrades    List packages newly available for upgrading
@@ -108,7 +108,7 @@ Run LIST-COMMANDS for a complete list of commands.
 
  addcdrom       Add a CD-ROM to the list of available sources of packages
  auto-alts      Mark the alternative to be auto set (using set priorities)
- auto-clean     Remove superseded deb files from the download cache
+ auto-clean     Remove superseded .deb files from the download cache
  auto-download  Do an update followed by a download of all updated packages
  auto-install   Perform an install without asking questions (non-interactive)
  available      List versions of packages available for installation
@@ -161,11 +161,12 @@ Run LIST-COMMANDS for a complete list of commands.
  list-orphans   List libraries not required by any installed package
  list-scripts   List the control scripts of the package of deb file
  list-section   List packages that belong to a specific section
- list-section   List the sections that are available
+ list-sections  List the sections that are available
  list-status    Same as list but only prints first two columns, not truncated
  list-wide      Same as list but avoids truncating package names
  local-dist-upgrade Dist-upgrade using packages already downloaded
  local-upgrade  Upgrade using packages already downloaded, but not any others
+ locate	        Search for a file within installed packages
  madison        Runs the madison command of apt-cache.
  move           Move packages in the download cache to a local Debian mirror
  new            List packages that became available since last update
@@ -215,11 +216,12 @@ Run LIST-COMMANDS for a complete list of commands.
  toupgrade      List packages with newer versions available for upgrading
  unhold         Remove listed packages from hold so they are again upgraded
  unofficial     Search for an unofficial Debian package at apt-get.org
- update         Update the list of down-loadable packages
+ update         Update the list of downloadable packages
  update-alts    Update default alternative for things like x-window-manager
  update-pci-ids Updates the local list of PCI ids from the internet master list
  update-usb-ids Updates the local list of USB ids from the internet master list
  upgrade        Upgrade all of the installed packages or just those listed
+ verify		Check the md5sums of a package.
  versions       List version and distribution of (all) packages.
  whatis         A synonym for describe
  whichpkg       Find the package that supplies the given command or file 
@@ -447,11 +449,12 @@ All wajig commands:
  list-names     List all known packages or those containing supplied string
  list-orphans   List libraries not required by any installed package
  list-section   List packages that belong to a specific section
- list-section   List the sections that are available
+ list-sections  List the sections that are available
  list-status    Same as list but only prints first two columns, not truncated
  list-wide      Same as list but avoids truncating package names
  local-dist-upgrade Dist-upgrade using packages already downloaded
  local-upgrade  Upgrade using packages already downloaded, but not any others
+ locate	        Search for a file within installed packages
  move           Move packages in the download cache to a local Debian mirror
  new            List packages that became available since last update
  news           Obtain the latest news about the package
@@ -499,9 +502,11 @@ All wajig commands:
  toupgrade      List packages with newer versions available for upgrading
  unhold         Remove listed packages from hold so they are again upgraded
  unofficial     Search for an unofficial Debian package at apt-get.org
- update         Update the list of down-loadable packages
+ update         Update the list of downloadable packages
  update-alts    Update default alternative for things like x-window-manager
  upgrade        Upgrade all of the installed packages or just those listed
+ verify		Check the md5sums of a package.
+ versions       List version and distribution of (all) packages.
  whatis         A synonym for describe
  whichpkg       Find the package that supplies the given command or file 
 
