@@ -469,7 +469,8 @@ def select_command(command, args, verbose, teaching):
             pkgs = string.join(map(string.strip,(open(args[1])).readlines()))
             perform.execute("apt-get remove " + pkgs, root=1)
 
-    elif command == "findfile":
+    elif command == "findfile" or \
+         command == "locate":
         if requires_one_arg(command, args, "a file name"):
             perform.execute("dpkg --search " + args[1])
 
@@ -948,6 +949,10 @@ def select_command(command, args, verbose, teaching):
         perform.execute(command, root=1)
         if os.path.exists(sources_list): os.remove(sources_list)
 
+    elif command == "verify":
+        if requires_one_arg(command, args, "a package name"):
+            perform.execute("debsums " + args[1])
+
     elif command == "version" or command == "versions":
         if command == "version" and len(args) == 1:
             documentation.version()
